@@ -14,7 +14,7 @@ _LOGGER = logging.getLogger(__name__)
 MODEL_PHILIPS_LIGHT_RWREAD = "philips.light.rwread"
 
 AVAILABLE_PROPERTIES = {
-    MODEL_PHILIPS_LIGHT_RWREAD: ["power", "bright", "dv", "snm", "flm", "chl", "flmv"],
+    MODEL_PHILIPS_LIGHT_RWREAD: ["power", "bright", "dv", "snm", "flm", "chl", "flmv"]
 }
 
 
@@ -139,16 +139,7 @@ class PhilipsRwread(Device):
     def status(self) -> PhilipsRwreadStatus:
         """Retrieve properties."""
         properties = AVAILABLE_PROPERTIES[self.model]
-        values = self.send("get_prop", properties)
-        properties_count = len(properties)
-        values_count = len(values)
-        if properties_count != values_count:
-            _LOGGER.debug(
-                "Count (%s) of requested properties does not match the "
-                "count (%s) of received values.",
-                properties_count,
-                values_count,
-            )
+        values = self.get_properties(properties)
 
         return PhilipsRwreadStatus(defaultdict(lambda: None, zip(properties, values)))
 
