@@ -130,18 +130,7 @@ class PwznRelay(Device):
         """Retrieve properties."""
 
         properties = AVAILABLE_PROPERTIES[self.model].copy()
-
-        values = self.send("get_prop", properties)
-
-        properties_count = len(properties)
-        values_count = len(values)
-        if properties_count != values_count:
-            _LOGGER.debug(
-                "Count (%s) of requested properties does not match the "
-                "count (%s) of received values.",
-                properties_count,
-                values_count,
-            )
+        values = self.get_properties(properties)
 
         return PwznRelayStatus(defaultdict(lambda: None, zip(properties, values)))
 
