@@ -70,6 +70,15 @@ class FanspeedE2(enum.Enum):
     Turbo = 100
 
 
+class WaterFlow:
+    """Water flow strength on s5 max. """
+
+    Minimum = 200
+    Low = 201
+    High = 202
+    Maximum = 203
+
+
 ROCKROBO_V1 = "rockrobo.vacuum.v1"
 
 
@@ -112,7 +121,7 @@ class Vacuum(Device):
     def resume_or_start(self):
         """A shortcut for resuming or starting cleaning."""
         status = self.status()
-        if status.in_zone_cleaning and status.is_paused:
+        if status.in_zone_cleaning and (status.is_paused or status.got_error):
             return self.resume_zoned_clean()
 
         return self.start()
@@ -540,7 +549,17 @@ class Vacuum(Device):
     @command()
     def timezone(self):
         """Get the timezone."""
-        return self.send("get_timezone")[0]
+        res = self.send("get_timezone")[0]
+        if isinstance(res, dict):
+            # Xiaowa E25 example
+            # {'olson': 'Europe/Berlin', 'posix': 'CET-1CEST,M3.5.0,M10.5.0/3'}
+            if "olson" not in res:
+                raise VacuumException("Unsupported timezone format: %s" % res)
+
+            return res["olson"]
+
+        # Gen1 vacuum: ['Europe/Berlin']
+        return res
 
     def set_timezone(self, new_zone):
         """Set the timezone."""
@@ -646,6 +665,16 @@ class Vacuum(Device):
         raise NotImplementedError("unknown parameters")
         # return self.send("split_segment")
 
+    @command()
+    def waterflow(self) -> WaterFlow:
+        """Get water flow setting."""
+        return WaterFlow(self.send("get_water_box_custom_mode")[0])
+
+    @command(click.argument("waterflow", type=WaterFlow))
+    def set_waterflow(self, waterflow: WaterFlow):
+        """Set water flow setting."""
+        return self.send("set_water_box_custom_mode", [waterflow.value])
+
     @classmethod
     def get_device_group(cls):
         @click.pass_context
